==> telnetserver-0.2.tar.gz: telnetserver-0.2/setup.py <==

from distutils.core import setup
setup(
  name = 'telnetserver',         # How you named your package folder (MyLib)
  packages = ['telnetserver'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Really simple and easy to use telnet server for small projects.',   # Give a short description about your library
  author = 'Óliver L. Sanz',                   # Type in your name
  author_email = 'oliverlsanz@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/OliverLSanz/Simple-Python-Telnet-Server',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/OliverLSanz/Simple-Python-Telnet-Server/archive/0.2.tar.gz',    # I explain this later on
  keywords = ['telnet', 'server', 'simple'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)

==> telnetserver-0.3.tar.gz: telnetserver-0.3/setup.py <==

from distutils.core import setup
setup(
  name = 'telnetserver',         # How you named your package folder (MyLib)
  packages = ['telnetserver'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Really simple and easy to use telnet server for small projects.',   # Give a short description about your library
  author = 'Óliver L. Sanz',                   # Type in your name
  author_email = 'oliverlsanz@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/OliverLSanz/Simple-Python-Telnet-Server',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/OliverLSanz/Simple-Python-Telnet-Server/archive/v0.3.tar.gz',    # I explain this later on
  keywords = ['telnet', 'server', 'simple'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
